@@ -7,7 +7,7 @@
 subgroup <- function(x, i) {
   n <- length(x)
   breaks <- (1:n)[is.na(x)]
-  if(length(breaks) == 0) {
+  if (length(breaks) == 0) {
     starts <- 1; ends <- n
   } else {
     starts <- c(1, breaks + 1)
@@ -16,7 +16,7 @@ subgroup <- function(x, i) {
   result <- numeric(0)
   for(j in i) {
     p <- x[starts[j]:ends[j]]
-    if(length(result) == 0) result <- p
+    if (length(result) == 0) result <- p
     else result <- c(result, NA, p)
   }
   result
@@ -32,23 +32,23 @@ sub.polygon <- function(p, i) {
 map.poly <- function(database, regions = ".", exact = FALSE,
                      xlim = NULL, ylim = NULL, boundary = TRUE,
 		     interior = TRUE, fill = FALSE, as.polygon = FALSE) {
-  if(!is.character(database)) {
-    if(!as.polygon) stop("map objects require as.polygon=TRUE")
+  if (!is.character(database)) {
+    if (!as.polygon) stop("map objects require as.polygon=TRUE")
     the.map <- database
-    if(identical(regions,".")) {
+    if (identical(regions,".")) {
       # speed up the common case
       nam = the.map$names
       coord <- the.map[c("x", "y")]
     } else {
       # same as mapname()
-      if(exact) {
+      if (exact) {
         i = match(regions, the.map$names)
-        if(any(is.na(i))) i = NULL
+        if (any(is.na(i))) i = NULL
       } else {
       regexp <- paste("(^", regions, ")", sep = "", collapse = "|")
         i <- grep(regexp, the.map$names, ignore.case = TRUE)
       }
-      if(length(i) == 0) stop("no recognized region names")
+      if (length(i) == 0) stop("no recognized region names")
       nam <- the.map$names[i]
       coord <- sub.polygon(the.map, i)
     }
@@ -57,15 +57,15 @@ map.poly <- function(database, regions = ".", exact = FALSE,
     # turn the polygon numbers into a list of polyline numbers
     gon <- mapname(database, regions, exact)
     n <- length(gon)
-    if(n == 0) stop("no recognized region names")
-    if(is.null(xlim)) xlim <- c(-1e+30, 1e+30)
-    if(is.null(ylim)) ylim <- c(-1e+30, 1e+30)
+    if (n == 0) stop("no recognized region names")
+    if (is.null(xlim)) xlim <- c(-1e+30, 1e+30)
+    if (is.null(ylim)) ylim <- c(-1e+30, 1e+30)
     # turn the polygon numbers into a list of polyline numbers
     line <- mapgetg(database, gon, as.polygon, xlim, ylim)
-    if(length(line$number) == 0)
+    if (length(line$number) == 0)
             stop("nothing to draw: all regions out of bounds")
     # turn the polyline numbers into x and y coordinates
-    if(as.polygon) {
+    if (as.polygon) {
       coord <- mapgetl(database, line$number, xlim, ylim, fill) 
       # assemble lines into polygons
       gonsize <- line$size
@@ -74,11 +74,11 @@ map.poly <- function(database, regions = ".", exact = FALSE,
     }
     else {
       l <- abs(line$number)
-      if(boundary && interior) l <- unique(l)
-      else if(boundary) l <- l[!match(l, l[duplicated(l)], FALSE)]
+      if (boundary && interior) l <- unique(l)
+      else if (boundary) l <- l[!match(l, l[duplicated(l)], FALSE)]
       else l <- l[duplicated(l)]
       coord <- mapgetl(database, l, xlim, ylim, fill)
-      if(length(coord) == 0)
+      if (length(coord) == 0)
               stop("all data out of bounds")
     }
     nam <- line$name
@@ -87,18 +87,18 @@ map.poly <- function(database, regions = ".", exact = FALSE,
 }
 
 map <-
-function(database = "world", regions = ".", exact = FALSE, boundary = TRUE, 
-         interior = TRUE, projection = "", parameters = NULL, 
-         orientation = NULL, fill = FALSE, col = 1,
-         plot = TRUE, add = FALSE, namesonly = FALSE, 
+function(database = "world", regions = ".", exact = FALSE,
+	 boundary = TRUE, interior = TRUE, projection = "",
+	 parameters = NULL, orientation = NULL, fill = FALSE,
+	 col = 1, plot = TRUE, add = FALSE, namesonly = FALSE, 
          xlim = NULL, ylim = NULL, wrap = FALSE,
-         resolution = if(plot) 1 else 0, type = "l",
-         bg = par("bg"), mar = c(0, 0, par("mar")[3], 0.1), ...)
+         resolution = if (plot) 1 else 0, type = "l", bg = par("bg"),
+         mar = c(0, 0, par("mar")[3], 0.1), border = 0.01, ...)
 {
   # parameter checks
-  if(resolution>0 && !plot) 
+  if (resolution>0 && !plot) 
     stop("must have plot=TRUE if resolution is given")
-  if(!fill && !boundary && !interior)
+  if (!fill && !boundary && !interior)
     stop("one of boundary and interior must be TRUE")
   doproj <- !missing(projection) || !missing(parameters) || !missing(
           orientation)
@@ -108,15 +108,15 @@ function(database = "world", regions = ".", exact = FALSE, boundary = TRUE,
   if (doproj && coordtype != "spherical") 
     stop(paste(database, "database is not spherical; projections not allowed"))
   # turn the region names into x and y coordinates
-  if(is.character(database)) as.polygon = fill
+  if (is.character(database)) as.polygon = fill
   else as.polygon = TRUE
   coord <- map.poly(database, regions, exact, xlim, ylim, 
                     boundary, interior, fill, as.polygon)
-  if(is.na(coord$x[1])) stop("first coordinate is NA.  bad map data?")
-  if(plot) {
+  if (is.na(coord$x[1])) stop("first coordinate is NA.  bad map data?")
+  if (plot) {
     assign(".map.range", coord$range, envir = globalenv())
   }
-  if(doproj) {
+  if (doproj) {
     nam <- coord$names
     library(mapproj)
     coord <- mapproject(coord, pr = projection, pa = parameters,
@@ -124,43 +124,37 @@ function(database = "world", regions = ".", exact = FALSE, boundary = TRUE,
     coord$projection = projection
     coord$parameters = parameters
     coord$orientation = orientation
-    if(plot && coord$error)
-      if(all(is.na(coord$x)))
+    if (plot && coord$error)
+      if (all(is.na(coord$x)))
         stop("projection failed for all data")
       else warning("projection failed for some data")
     coord$names <- nam
   }
   # do the plotting, if requested
-  if(plot) {
+  if (plot) {
     # for new plots, set up the coordinate system;
     # if a projection was done, set the aspect ratio
     # to 1, else set it so that a long-lat square appears
     # square in the middle of the plot
-    if(!add) {
-      # this doesn't work until R's par() mechanism is fixed
-      #par(mar = mar, xpd = TRUE)
+    if (!add) {
       opar = par(bg = bg)
-      if(!par("new")) plot.new()
+      if (!par("new")) plot.new()
       # xlim, ylim apply before projection
-      if(is.null(xlim) || doproj) xrange <- range(coord$x, na.rm = TRUE)
+      if (is.null(xlim) || doproj) xrange <- range(coord$x, na.rm = TRUE)
       else xrange <- xlim
-      if(is.null(ylim) || doproj) yrange <- range(coord$y, na.rm = TRUE)
+      if (is.null(ylim) || doproj) yrange <- range(coord$y, na.rm = TRUE)
       else yrange <- ylim
-      border <- c(0.01, 0.01)
-      if(coordtype != "spherical" || doproj) {
+      if (coordtype != "spherical" || doproj) {
 	aspect <- c(1, 1) 
       } else
         aspect <- c(cos((mean(yrange) * pi)/180), 1)
-      d <- c(diff(xrange), diff(yrange)) * aspect
-      if(coordtype != "spherical" || doproj) {
-        plot.window(xrange, yrange, asp = aspect[2]/aspect[1])
-        #set.aspect(aspect[2]/aspect[1])
-        #layout(1, width = aspect[1], height = aspect[2], respect = TRUE)
-        #on.exit(layout(1), add = TRUE)
+      d <- c(diff(xrange), diff(yrange)) * (1 + 2 * border) * aspect
+      if (coordtype != "spherical" || doproj) {
+        plot.window(xrange, yrange, asp = 1/aspect[1])
       } else {
         # must have par(xpd = FALSE) for limits to have an effect ??!
 	p <- par("fin") -
-	  as.vector(matrix(c(0,1,1,0,0,1,1,0), nrow=2) %*% par("mai"))
+	  as.vector(matrix(c(0, 1, 1, 0, 0, 1, 1, 0), nrow = 2) %*% par("mai"))
 	par(pin = p)
         p <- par("pin")
         p <- d * min(p/d)
@@ -172,22 +166,22 @@ function(database = "world", regions = ".", exact = FALSE, boundary = TRUE,
       on.exit(par(opar))
     }
     # thinning only works if you have polylines from a database
-    if(is.character(database) && resolution != 0 && type != "n") {
+    if (is.character(database) && resolution != 0 && type != "n") {
       pin <- par("pin")
       usr <- par("usr")
       resolution <- resolution * min(diff(usr)[-2]/pin/100)
       coord[c("x", "y")] <- mapthin(coord, resolution)
     }
-    if(type != "n") {
-      if(wrap) coord = map.wrap(coord)
+    if (type != "n") {
+      if (wrap) coord = map.wrap(coord)
       if (fill) polygon(coord, col = col, ...)
       else lines(coord, col = col, type = type, ...)
     }
   }
   # return value is names or coords, but not both
   class(coord) = "map"
-  value <- if(namesonly) coord$names else coord
-  if(plot) invisible(value)
+  value <- if (namesonly) coord$names else coord
+  if (plot) invisible(value)
   else value
 }
 
@@ -204,7 +198,7 @@ function(xy, gonsize, keep)
   n <- length(x)
   gonsize <- gonsize[ - length(gonsize)]
   discard <- seq(length(x))[is.na(x)]
-  if(length(discard) > 0) {
+  if (length(discard) > 0) {
     # locations of (possible) duplicate points
     dups = c(discard - 1, n)
     # only polylines with > 1 point have duplicates
@@ -213,9 +207,9 @@ function(xy, gonsize, keep)
   }
   # first part of discard is the NAs, second part is duplicates
   # gonsize tells us which NAs to preserve
-  if(length(gonsize) > 0)
+  if (length(gonsize) > 0)
     discard <- discard[ - cumsum(gonsize)]
-  if(length(discard) > 0) {
+  if (length(discard) > 0) {
     x <- x[ - discard]
     y <- y[ - discard]
   }
